@@ -35,7 +35,7 @@ enum
 typedef struct
 {
 	Git *plugin;
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	GtkListStore *list_store;
 	GtkCellRenderer *graph_renderer;
 	gchar *path;
@@ -125,7 +125,7 @@ create_columns (LogData *data)
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 	
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
 	font_size = PANGO_PIXELS (pango_font_description_get_size (GTK_WIDGET (log_changes_view)->style->font_desc));
 	
 	/* Ref info */
@@ -210,7 +210,7 @@ on_log_command_finished (AnjutaCommand *command, guint return_code,
 		return;
 	}
 	
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
 	
 	g_object_ref (data->list_store);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (log_changes_view), NULL);
@@ -242,6 +242,10 @@ on_ref_command_finished (AnjutaCommand *command, guint return_code,
 {
 	gchar *path;
 	const gchar *relative_path;
+	GtkWidget *log_branch_combo;
+	GtkTreeModel *log_branch_combo_model;
+	GtkTreeIter iter;
+	gchar *branch;
 	GtkWidget *log_changes_view;
 	GtkTreeViewColumn *graph_column;
 	gchar *author;
@@ -273,9 +277,16 @@ on_ref_command_finished (AnjutaCommand *command, guint return_code,
 	/* If the user is using any filters or getting the log of an individual,
 	 * file or folder, hide the graph column, because we can't be assured that  
 	 * the graph will be correct in these cases */
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
+	log_branch_combo_model = GTK_TREE_MODEL (gtk_builder_get_object (data->bxml, 
+	                                                                 "log_branch_combo_model"));
+	log_branch_combo = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+	                                                       "log_branch_combo"));
 	graph_column = gtk_tree_view_get_column (GTK_TREE_VIEW (log_changes_view),
 											 1);
+
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (log_branch_combo), &iter);
+	gtk_tree_model_get (log_branch_combo_model, &iter, 1, &branch, -1);
 	
 	if (g_hash_table_size (data->filters) > 0 || path)
 		gtk_tree_view_column_set_visible (graph_column, FALSE);
@@ -295,7 +306,7 @@ on_ref_command_finished (AnjutaCommand *command, guint return_code,
 	
 	data->refs = git_ref_command_get_refs (GIT_REF_COMMAND (command));
 	log_command = git_log_command_new (data->plugin->project_root_directory,
-									   relative_path,
+									   branch, relative_path,
 									   author, grep, since_date, until_date,
 									   since_commit, until_commit);
 	
@@ -329,12 +340,13 @@ on_log_view_button_clicked (GtkButton *button, LogData *data)
 	
 	path = NULL;
 	
-	log_whole_project_check = glade_xml_get_widget (data->gxml,
-													"log_whole_project_check");
+	log_whole_project_check = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+										  "log_whole_project_check"));
 	
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (log_whole_project_check)))
 	{
-		log_path_entry = glade_xml_get_widget (data->gxml, "log_path_entry");
+		log_path_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+		                                                     "log_path_entry"));
 		path = gtk_editable_get_chars (GTK_EDITABLE (log_path_entry), 0, -1);
 		
 		/* Log widget belongs to the shell at this point. */
@@ -375,11 +387,42 @@ on_log_view_button_clicked (GtkButton *button, LogData *data)
 	anjuta_command_start (ANJUTA_COMMAND (ref_command));
 }
 
+static void
+on_log_browse_button_clicked (GtkButton *button, LogData *data)
+{
+	GtkWidget *log_file_entry;
+	GtkWidget *file_chooser_dialog;
+	gchar *filename;
+	gint response;
+
+	log_file_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+	                                                     "log_path_entry"));
+
+	file_chooser_dialog = gtk_file_chooser_dialog_new (_("Select a file"),
+	                                                   NULL,
+	                                                   GTK_FILE_CHOOSER_ACTION_OPEN,
+				  									   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				  									   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+				  									   NULL);
+
+	response = gtk_dialog_run (GTK_DIALOG (file_chooser_dialog));
+
+	if (response == GTK_RESPONSE_ACCEPT)
+	{
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_chooser_dialog));
+		gtk_entry_set_text (GTK_ENTRY (log_file_entry), filename);
+
+		g_free (filename);
+	}
+
+	gtk_widget_destroy (file_chooser_dialog);
+}
+
 static void
 on_log_vbox_destroy (GtkObject *log_vbox, LogData *data)
 {
 	g_free (data->path);
-	g_object_unref (data->gxml);
+	g_object_unref (data->bxml);
 	
 	if (data->refs)
 		g_hash_table_unref (data->refs);
@@ -397,7 +440,7 @@ on_log_message_command_finished (AnjutaCommand *command, guint return_code,
 	GtkTextBuffer *buffer;
 	gchar *log_message;
 	
-	log_text_view = glade_xml_get_widget (data->gxml, "log_text_view");
+	log_text_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_text_view"));
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (log_text_view));
 	log_message = git_log_message_command_get_message (GIT_LOG_MESSAGE_COMMAND (command));
 	
@@ -628,18 +671,18 @@ on_log_filter_clear_button_clicked (GtkButton *button, LogData *data)
 	GtkWidget *log_filter_from_entry;
 	GtkWidget *log_filter_to_entry;
 	
-	log_filter_author_entry = glade_xml_get_widget (data->gxml,
-													"log_filter_author_entry");
-	log_filter_grep_entry = glade_xml_get_widget (data->gxml,
-												  "log_filter_grep_entry");
-	log_filter_from_check = glade_xml_get_widget (data->gxml,
-												  "log_filter_from_check");
-	log_filter_to_check = glade_xml_get_widget (data->gxml,
-												"log_filter_to_check");
-	log_filter_from_entry = glade_xml_get_widget (data->gxml,
-												  "log_filter_from_entry");
-	log_filter_to_entry = glade_xml_get_widget (data->gxml,
-												"log_filter_to_entry");
+	log_filter_author_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																  "log_filter_author_entry"));
+	log_filter_grep_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																"log_filter_grep_entry"));
+	log_filter_from_check = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																"log_filter_from_check"));
+	log_filter_to_check = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+															  "log_filter_to_check"));
+	log_filter_from_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																"log_filter_from_entry"));
+	log_filter_to_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+															  "log_filter_to_entry"));
 	
 	gtk_entry_set_text (GTK_ENTRY (log_filter_author_entry), "");
 	gtk_entry_set_text (GTK_ENTRY (log_filter_grep_entry), "");
@@ -670,24 +713,24 @@ setup_filters (LogData *data)
 	data->filters = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, 
 										   g_free);
 	
-	log_filter_author_entry = glade_xml_get_widget (data->gxml,
-													"log_filter_author_entry");
-	log_filter_grep_entry = glade_xml_get_widget (data->gxml,
-												  "log_filter_grep_entry");
-	log_filter_from_check = glade_xml_get_widget (data->gxml,
-												  "log_filter_from_check");
-	log_filter_to_check = glade_xml_get_widget (data->gxml,
-												"log_filter_to_check");
-	log_filter_from_calendar = glade_xml_get_widget (data->gxml,
-													 "log_filter_from_calendar");
-	log_filter_to_calendar = glade_xml_get_widget (data->gxml,
-												   "log_filter_to_calendar");
-	log_filter_from_entry = glade_xml_get_widget (data->gxml,
-												  "log_filter_from_entry");
-	log_filter_to_entry = glade_xml_get_widget (data->gxml,
-												"log_filter_to_entry");
-	log_filter_clear_button = glade_xml_get_widget (data->gxml,
-													"log_filter_clear_button");
+	log_filter_author_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																  "log_filter_author_entry"));
+	log_filter_grep_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																"log_filter_grep_entry"));
+	log_filter_from_check = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																"log_filter_from_check"));
+	log_filter_to_check = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+															  "log_filter_to_check"));
+	log_filter_from_calendar = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																   "log_filter_from_calendar"));
+	log_filter_to_calendar = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+															     "log_filter_to_calendar"));
+	log_filter_from_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																"log_filter_from_entry"));
+	log_filter_to_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+															  "log_filter_to_entry"));
+	log_filter_clear_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																  "log_filter_clear_button"));
 	
 	/* Each widget that has some kind of filter must have a "filter name"
 	 * associated with it so that we can generically see how many filters 
@@ -760,33 +803,160 @@ setup_filters (LogData *data)
 					  data);
 }
 
+static void
+on_log_list_branch_command_data_arrived (AnjutaCommand *command,
+                                         GtkBuilder *bxml)
+{
+	GtkListStore *log_branch_combo_model;
+	GtkComboBox *log_branch_combo;
+	GHashTable *branches_table;
+	GQueue *output_queue;
+	GitBranch *branch;
+	GtkTreeIter iter;
+	gchar *name;
+	
+	log_branch_combo_model = GTK_LIST_STORE (gtk_builder_get_object (bxml, 
+	                                                                 "log_branch_combo_model"));
+	log_branch_combo = GTK_COMBO_BOX (gtk_builder_get_object (bxml,
+	                                                          "log_branch_combo"));
+	branches_table = g_object_get_data (G_OBJECT (log_branch_combo), 
+	                                    "branches-table");
+	output_queue = git_branch_list_command_get_output (GIT_BRANCH_LIST_COMMAND (command));
+
+	while (g_queue_peek_head (output_queue))
+	{
+		branch = g_queue_pop_head (output_queue);
+		name = git_branch_get_name (branch);
+
+		gtk_list_store_append (log_branch_combo_model, &iter);
+		
+		if (git_branch_is_active (branch))
+		{
+			gtk_list_store_set (log_branch_combo_model, &iter, 0, 
+			                    GTK_STOCK_APPLY, -1);
+			gtk_combo_box_set_active_iter (log_branch_combo, &iter);
+		}
+		
+		gtk_list_store_set (log_branch_combo_model, &iter, 1, name, -1);
+		g_hash_table_insert (branches_table, g_strdup (name), 
+		                     g_memdup (&iter, sizeof (GtkTreeIter)));
+
+		g_object_unref (branch);
+		g_free (name);
+	}
+}
+
+static void
+on_log_list_branch_command_finished (AnjutaCommand *command, guint return_code,
+                                     GtkBuilder *bxml)
+{
+	GtkComboBox *log_branch_combo;
+	GHashTable *branches_table;
+	gchar *selected_branch;
+	GtkTreeIter *iter;
+
+	log_branch_combo = GTK_COMBO_BOX (gtk_builder_get_object (bxml,
+	                                                          "log_branch_combo"));
+	branches_table = g_object_get_data (G_OBJECT (log_branch_combo),
+	                                    "branches-table");
+	selected_branch = g_object_get_data (G_OBJECT (log_branch_combo),
+	                                     "selected-branch");
+
+	if (selected_branch)
+	{	
+		if (g_hash_table_lookup_extended (branches_table, selected_branch, NULL,
+		                                  (gpointer *) &iter))
+		{
+			gtk_combo_box_set_active_iter (log_branch_combo, iter);
+		}
+	}
+
+	g_object_set_data (G_OBJECT (log_branch_combo), "being-refreshed",
+	                   GINT_TO_POINTER (FALSE));
+
+	g_object_unref (command);
+	
+}
+
+static void
+on_log_branch_combo_changed (GtkComboBox *combo_box, gpointer user_data)
+{
+	GtkTreeModel *log_branch_combo_model;
+	gchar *branch;
+	GtkTreeIter iter;
+
+	log_branch_combo_model = gtk_combo_box_get_model (combo_box);
+
+	if (gtk_combo_box_get_active_iter (combo_box, &iter))
+	{
+		gtk_tree_model_get (log_branch_combo_model, &iter, 1, &branch, -1);
+
+		g_object_set_data_full (G_OBJECT (combo_box), "selected-branch", 
+		                        branch, (GDestroyNotify) g_free);
+	}
+}
+
+static void 
+on_log_refresh_monitor_changed (GFileMonitor *file_monitor, GFile *file,
+								GFile *other_file, GFileMonitorEvent event_type,
+								Git *plugin)
+{
+	if (event_type == G_FILE_MONITOR_EVENT_CREATED ||
+	    event_type == G_FILE_MONITOR_EVENT_DELETED)
+	{
+		git_log_refresh_branches (plugin);
+	}
+}
+
+
 GtkWidget *
 git_log_window_create (Git *plugin)
 {
 	LogData *data;
+	gchar *objects[] = {"log_window", "log_branch_combo_model", NULL};
+	GError *error;
 	GtkWidget *log_window;
 	GtkWidget *log_vbox;
 	GtkWidget *log_changes_view;
 	GtkWidget *log_view_button;
+	GtkWidget *log_browse_button;
 	GtkWidget *log_whole_project_check;
 	GtkWidget *log_path_entry;
+	GtkWidget *log_path_entry_hbox;
+	GtkWidget *log_branch_combo;
 	GtkTreeSelection *selection;
 	
 	data = g_new0 (LogData, 1);
-	data->gxml = glade_xml_new (GLADE_FILE, "log_window", NULL);
+	data->bxml = gtk_builder_new ();
+	error = NULL;
+
+	if (!gtk_builder_add_objects_from_file (data->bxml, BUILDER_FILE, objects, 
+	                                        &error))
+	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
 	
 	data->plugin = plugin;
 	data->path = NULL;
 	data->graph_renderer = giggle_graph_renderer_new ();
 	
-	log_window = glade_xml_get_widget (data->gxml, "log_window");
-	log_vbox = glade_xml_get_widget (data->gxml, "log_vbox");
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
-	log_whole_project_check = glade_xml_get_widget (data->gxml, 
-													"log_whole_project_check");
-	log_path_entry = glade_xml_get_widget (data->gxml, "log_path_entry");
-	log_view_button = glade_xml_get_widget (data->gxml, 
-											"log_view_button");
+	log_window = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_window"));
+	log_vbox = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_vbox"));
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+	                                                       "log_changes_view"));
+	log_view_button = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+														  "log_view_button"));
+	log_browse_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+	                                                        "log_browse_button"));
+	log_whole_project_check = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+																  "log_whole_project_check"));
+	log_path_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+	                                                     "log_path_entry"));
+	log_path_entry_hbox = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+	                                                          "log_path_entry_hbox"));
+	log_branch_combo = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+	                                                       "log_branch_combo"));
 	
 	g_object_set_data (G_OBJECT (log_vbox), "log-data", data);
 	
@@ -795,6 +965,7 @@ git_log_window_create (Git *plugin)
 	g_signal_connect (G_OBJECT (log_changes_view), "query-tooltip",
 					  G_CALLBACK (on_log_changes_view_query_tooltip),
 					  data);
+	
 	g_signal_connect (G_OBJECT (log_changes_view), "button-press-event",
 					  G_CALLBACK (on_log_changes_view_button_press_event),
 					  plugin);
@@ -803,11 +974,20 @@ git_log_window_create (Git *plugin)
 	g_signal_connect (G_OBJECT (log_view_button), "clicked",
 					  G_CALLBACK (on_log_view_button_clicked),
 					  data);
+
+	g_signal_connect (G_OBJECT (log_browse_button), "clicked",
+	                  G_CALLBACK (on_log_browse_button_clicked),
+	                  data);
 	
 	g_object_set_data (G_OBJECT (log_whole_project_check), "file-entry",
-					   log_path_entry);
+					   log_path_entry_hbox);
+	                  
 	g_signal_connect (G_OBJECT (log_whole_project_check), "toggled",
 					  G_CALLBACK (on_git_whole_project_toggled), plugin);
+
+	g_signal_connect (G_OBJECT (log_branch_combo), "changed",
+	                  G_CALLBACK (on_log_branch_combo_changed),
+	                  NULL);
 	
 	data->list_store = gtk_list_store_new (NUM_COLS,
 										   G_TYPE_OBJECT);
@@ -846,10 +1026,10 @@ on_fm_git_log (GtkAction *action, Git *plugin)
 	GtkWidget *log_whole_project_check;
 	
 	data = g_object_get_data (G_OBJECT (plugin->log_viewer), "log-data");
-	log_path_entry = glade_xml_get_widget (data->gxml, 
-										   "log_path_entry");
-	log_whole_project_check = glade_xml_get_widget (data->gxml,
-													"log_whole_project_check");
+	log_path_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+														 "log_path_entry"));
+	log_whole_project_check = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+																  "log_whole_project_check"));
 	
 	gtk_entry_set_text (GTK_ENTRY (log_path_entry), 
 						plugin->current_fm_filename);
@@ -868,7 +1048,7 @@ git_log_window_clear (Git *plugin)
 	GtkTextBuffer *buffer;
 	
 	data = g_object_get_data (G_OBJECT (plugin->log_viewer), "log-data");
-	log_text_view = glade_xml_get_widget (data->gxml, "log_text_view");
+	log_text_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_text_view"));
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (log_text_view));
 	
 	gtk_list_store_clear (data->list_store);
@@ -886,7 +1066,8 @@ git_log_get_selected_revision (Git *plugin)
 	GtkTreeIter iter;
 	
 	data = g_object_get_data (G_OBJECT (plugin->log_viewer), "log-data");
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+	                                                       "log_changes_view"));
 	revision = NULL;
 	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (log_changes_view));
@@ -905,7 +1086,93 @@ git_log_get_path (Git *plugin)
 	GtkWidget *log_path_entry;
 	
 	data = g_object_get_data (G_OBJECT (plugin->log_viewer), "log-data");
-	log_path_entry = glade_xml_get_widget (data->gxml, "log_path_entry");
+	log_path_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+	                                                     "log_path_entry"));
 	
 	return gtk_editable_get_chars (GTK_EDITABLE (log_path_entry), 0, -1);
 }
+
+GFileMonitor *
+git_log_setup_refresh_monitor (Git *plugin)
+{
+	gchar *git_ref_path;
+	GFile *git_ref_file;
+	GFileMonitor *git_ref_monitor;
+
+	git_ref_path = g_strjoin (G_DIR_SEPARATOR_S,
+	                          plugin->project_root_directory,
+	                          ".git",
+	                          "refs",
+	                          "heads",
+	                          NULL);
+
+	git_ref_file = g_file_new_for_path (git_ref_path);
+	git_ref_monitor = g_file_monitor_directory (git_ref_file, 0, NULL, NULL);
+
+	g_file_monitor_set_rate_limit (git_ref_monitor, 1000);
+
+	
+
+	g_signal_connect (G_OBJECT (git_ref_monitor), "changed",
+	                  G_CALLBACK (on_log_refresh_monitor_changed),
+	                  plugin);
+
+	g_free (git_ref_path);
+	g_object_unref (git_ref_file);
+
+	return git_ref_monitor;
+}
+
+void
+git_log_refresh_branches (Git *plugin)
+{
+	LogData *data;
+	GtkWidget *log_branch_combo;
+	gboolean being_refreshed;
+	GtkListStore *log_branch_combo_model;
+	GHashTable *branches_table;
+	GitBranchListCommand *branch_list_command;
+
+	data = g_object_get_data (G_OBJECT (plugin->log_viewer), "log-data");
+	log_branch_combo = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+	                                                       "log_branch_combo"));
+	/* Don't refresh if another refresh is already in progress. The file monitor
+	 * may trigger more than one concurrent refresh, which would populate the  
+	 * combo box several times. The command-finished handler will set the 
+	 * being-refreshed  flag to FALSE when this refresh finishes,  
+	 * allowing the next refresh to go forward. */
+	being_refreshed = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (log_branch_combo),
+	                                                      "being-refreshed"));
+
+	if (!being_refreshed)
+	{
+		log_branch_combo_model = GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (log_branch_combo)));
+		branches_table = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, 
+		                                        g_free);
+		branch_list_command = git_branch_list_command_new (plugin->project_root_directory,
+		                                                   GIT_BRANCH_TYPE_ALL);
+
+		gtk_list_store_clear (log_branch_combo_model);
+
+		/* The branches table keeps track of branch names and iters in the combo
+		 * model, so that the branch that was selected before we refreshed can be
+		 * selected again automatically. If that branch doesn't exist, then
+		 * the currently active branch will be selected. */
+		g_object_set_data_full (G_OBJECT (log_branch_combo), "branches-table",
+		                        branches_table, (GDestroyNotify) g_hash_table_destroy);
+
+		g_signal_connect (G_OBJECT (branch_list_command), "data-arrived",
+		                  G_CALLBACK (on_log_list_branch_command_data_arrived),
+		                  data->bxml);
+
+		g_signal_connect (G_OBJECT (branch_list_command), "command-finished",
+		                  G_CALLBACK (on_log_list_branch_command_finished),
+		                  data->bxml);
+
+		g_object_set_data (G_OBJECT (log_branch_combo), "being-refreshed",
+		                   GINT_TO_POINTER (TRUE));
+
+		anjuta_command_start (ANJUTA_COMMAND (branch_list_command));
+	}
+	
+}
