@@ -43,7 +43,7 @@ extern GType git_get_type (GTypeModule *module);
 typedef struct _Git Git;
 typedef struct _GitClass GitClass;
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-git.glade"
+#define BUILDER_FILE PACKAGE_DATA_DIR"/glade/anjuta-git.ui"
 #define ICON_FILE "anjuta-git-plugin-48.png"
 
 struct _Git
@@ -65,6 +65,7 @@ struct _Git
 	
 	/* File monitors */
 	GFileMonitor *bisect_file_monitor;
+	GFileMonitor *log_refresh_monitor;
 };
 
 struct _GitClass
